@@ -1,13 +1,13 @@
 # Copyrights 2007 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.00.
+# Pod stripped from pm file by OODoc 1.02.
 use warnings;
 use strict;
 
 package Log::Report::Dispatcher;
 use vars '$VERSION';
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 use Log::Report 'log-report', syntax => 'SHORT';
 use Log::Report::Util qw/parse_locale expand_reasons %reason_code
@@ -169,7 +169,9 @@ sub translate($$$)
           . "\n";
     }
 
-    setlocale(LC_ALL, $oldloc);
+    setlocale(LC_ALL, $oldloc)
+        if defined $oldloc;
+
     $text;
 }
 
